summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/skymap.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kstars/kstars/skymap.cpp')
-rw-r--r--kstars/kstars/skymap.cpp46
1 files changed, 23 insertions, 23 deletions
diff --git a/kstars/kstars/skymap.cpp b/kstars/kstars/skymap.cpp
index 13a5ab45..27f72614 100644
--- a/kstars/kstars/skymap.cpp
+++ b/kstars/kstars/skymap.cpp
@@ -51,13 +51,13 @@
#include "starobject.h"
#include "customcatalog.h"
-SkyMap::SkyMap(KStarsData *d, TQWidget *parent, const char *name )
- : TQWidget (parent,name), computeSkymap(true), angularDistanceMode(false),
+SkyMap::SkyMap(KStarsData *d, TQWidget *tqparent, const char *name )
+ : TQWidget (tqparent,name), computeSkymap(true), angularDistanceMode(false),
ksw(0), data(d), pmenu(0), sky(0), sky2(0), IBoxes(0),
ClickedObject(0), FocusObject(0), TransientObject(0),
starpix(0), pts(0), sp(0)
{
- if ( parent ) ksw = (KStars*) parent->parent();
+ if ( tqparent ) ksw = (KStars*) tqparent->tqparent();
else ksw = 0;
pts = new TQPointArray( 2000 ); // points for milkyway and horizon
@@ -72,9 +72,9 @@ SkyMap::SkyMap(KStarsData *d, TQWidget *parent, const char *name )
setBackgroundColor( TQColor( data->colorScheme()->colorNamed( "SkyColor" ) ) );
setBackgroundMode( TQWidget::NoBackground );
- setFocusPolicy( TQWidget::StrongFocus );
+ setFocusPolicy( TQ_StrongFocus );
setMinimumSize( 380, 250 );
- setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Expanding ) );
+ tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Expanding ) );
setMouseTracking (true); //Generate MouseMove events!
midMouseButtonDown = false;
@@ -121,7 +121,7 @@ SkyMap::SkyMap(KStarsData *d, TQWidget *parent, const char *name )
connect( this, TQT_SIGNAL( destinationChanged() ), this, TQT_SLOT( slewFocus() ) );
//Initialize Refraction correction lookup table arrays. RefractCorr1 is for calculating
//the apparent altitude from the true altitude, and RefractCorr2 is for the reverse.
for ( unsigned int index = 0; index <184; ++index ) {
double alt = -1.75 + index*0.5; //start at -1.75 degrees to get midpoint value for each interval.
@@ -925,7 +925,7 @@ void SkyMap::slewFocus( void ) {
fadeTransientLabel();
forceUpdate();
- kapp->processEvents(10); //keep up with other stuff
+ kapp->tqprocessEvents(10); //keep up with other stuff
if ( Options::useAltAz() ) {
dX = destination()->az()->Degrees() - focus()->az()->Degrees();
@@ -1102,7 +1102,7 @@ SkyPoint SkyMap::dXdYToRaDec( double dx, double dy, bool useAltAz, dms *LST, con
az = focus()->az()->Degrees() + deltaAz.Degrees();
alt.setRadians( asin( cosc*sinAlt0 + ( dy*sinc*cosAlt0 )/r ) );
- if ( doRefract ) alt.setD( refract( &alt, false ).Degrees() ); //find true altitude from apparent altitude
+ if ( doRefract ) alt.setD( refract( &alt, false ).Degrees() ); //find true altitude from aptqparent altitude
az.SinCos( sinAz, cosAz );
alt.SinCos( sinAlt, cosAlt );
@@ -1141,7 +1141,7 @@ SkyPoint SkyMap::dXdYToRaDec( double dx, double dy, bool useAltAz, dms *LST, con
}
}
-dms SkyMap::refract( const dms *alt, bool findApparent ) {
+dms SkyMap::refract( const dms *alt, bool findAptqparent ) {
if ( alt->Degrees() <= -2.000 ) return dms( alt->Degrees() );
int index = int( ( alt->Degrees() + 2.0 )*2. ); //RefractCorr arrays start at alt=-2.0 degrees.
@@ -1152,7 +1152,7 @@ dms SkyMap::refract( const dms *alt, bool findApparent ) {
return dms( alt->Degrees() );
}
- if ( findApparent ) {
+ if ( findAptqparent ) {
result.setD( alt->Degrees() + RefractCorr1[index] );
} else {
result.setD( alt->Degrees() + RefractCorr2[index] );
@@ -1179,7 +1179,7 @@ void SkyMap::forceUpdate( bool now )
}
computeSkymap = true;
- if ( now ) repaint();
+ if ( now ) tqrepaint();
else update();
}
@@ -1195,7 +1195,7 @@ bool SkyMap::checkVisibility( SkyPoint *p, float FOV, double XMax ) {
bool useAltAz = Options::useAltAz();
//Skip objects below the horizon if:
- // + using Horizontal coords,
+ // + usingQt::Horizontal coords,
// + the ground is drawn,
// + and either of the following is true:
// - focus is above the horizon
@@ -1252,18 +1252,18 @@ void SkyMap::setZoomMouseCursor()
p.drawLine( mx + 5, my + 5, mx + 11, my + 11 );
p.end();
-// create a mask to make parts of the pixmap invisible
- TQBitmap mask (32, 32);
- mask.fill (color0); // all is invisible
+// create a tqmask to make parts of the pixmap invisible
+ TQBitmap tqmask (32, 32);
+ tqmask.fill (color0); // all is invisible
- p.begin (&mask);
+ p.begin (&tqmask);
// paint over the parts which should be visible
p.setPen (TQPen (color1, 3));
p.drawEllipse( mx - 7, my - 7, 14, 14 );
p.drawLine( mx + 5, my + 5, mx + 12, my + 12 );
p.end();
- cursorPix.setMask (mask); // set the mask
+ cursorPix.setMask (tqmask); // set the tqmask
TQCursor cursor (cursorPix);
setCursor (cursor);
}
@@ -1289,11 +1289,11 @@ void SkyMap::setDefaultMouseCursor()
p.drawLine (mx + 2, my - 2, mx + 8, mx - 8);
p.end();
-// create a mask to make parts of the pixmap invisible
- TQBitmap mask (32, 32);
- mask.fill (color0); // all is invisible
+// create a tqmask to make parts of the pixmap invisible
+ TQBitmap tqmask (32, 32);
+ tqmask.fill (color0); // all is invisible
- p.begin (&mask);
+ p.begin (&tqmask);
// paint over the parts which should be visible
p.setPen (TQPen (color1, 3));
// 1. diagonal
@@ -1304,7 +1304,7 @@ void SkyMap::setDefaultMouseCursor()
p.drawLine (mx + 2, my - 2, mx + 8, mx - 8);
p.end();
- cursorPix.setMask (mask); // set the mask
+ cursorPix.setMask (tqmask); // set the tqmask
TQCursor cursor (cursorPix);
setCursor (cursor);
}
@@ -1313,7 +1313,7 @@ void SkyMap::setMouseMoveCursor()
{
if (mouseButtonDown)
{
- setCursor (9); // cursor shape defined in qt
+ setCursor (9); // cursor tqshape defined in qt
mouseMoveCursor = true;
}
}
@@ -121,7 +121,7 @@ SkyMap::SkyMap(KStarsData *d, TQWidget *parent, const char *name )
connect( this, TQT_SIGNAL( destinationChanged() ), this, TQT_SLOT( slewFocus() ) );
//Initialize Refraction correction lookup table arrays. RefractCorr1 is for calculating
- //the apparent altitude from the true altitude, and RefractCorr2 is for the reverse.
+ //the aptqparent altitude from the true altitude, and RefractCorr2 is for the reverse.
for ( unsigned int index = 0; index <184; ++index ) {
double alt = -1.75 + index*0.5; //start at -1.75 degrees to get midpoint value for each interval.